@@ -9,7 +9,7 @@ neighborhoods. The aim of this script is to resolve conflict files of both
 types.
 """
 
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 # pylint: disable=C0103, C0111, W0105, W0141, W0142
 
@@ -66,8 +66,11 @@ class BaseDeleter(FileManipulator):
 
     def apply(self):
         for f in self.files:
-            self.action(str(f))
-            logger.info(self.__class__.log_message.format(f))
+            try:
+                self.action(str(f))
+                logger.info(self.__class__.log_message.format(f))
+            except FileNotFoundError:
+                logger.debug("File not found: {}, not deleting it".format(f))
 
     def delete(self, file_path):
         self.files.append(file_path)
@@ -95,8 +98,14 @@ class BaseRenamer(FileManipulator):
 
     def apply(self):
         for src, dst in self.files.items():
-            self.action(str(src), str(dst))
-            logger.info(self.__class__.log_message.format(src, dst))
+            try:
+                self.action(str(src), str(dst))
+                logger.info(self.__class__.log_message.format(src, dst))
+            except FileNotFoundError:
+                logger.debug("File not found: {}, not renaming it".format(src))
+            except FileExistsError:
+                logger.debug("File exists: {dst}, not renaming {src} -> {dst} "
+                             "it".format(src=src, dst=dst))
 
     def rename(self, src, dst):
         self.files[src] = dst
@@ -158,7 +167,7 @@ class ConflictResolver:
         'seafile': r" \(.*@.* \d{4}-[01]\d-[0-3]\d-[0-2]\d-[0-5]\d-[0-5]\d\)",
     }
 
-    def __init__(self, root=Path('.'), deleter=RemoveDeleter, renamer=Renamer,
+    def __init__(self, root=Path('.'), *, deleter=RemoveDeleter, renamer=Renamer,
                  program=Program(), backup=True):
         self.root = root
         self.deleter = deleter()
@@ -269,7 +278,7 @@ class CompareConflictResolver(ConflictResolver):
         if keep is Keep.none:
             self.deleter.delete(conflict_file_path)
             self.deleter.delete(normal_file_path)
-        if keep is Keep.conflict:
+        elif keep is Keep.conflict:
             self.deleter.delete(normal_file_path)
             self.renamer.rename_conflict_to_normal_file(conflict_file_path)
         elif keep is Keep.normal:
@@ -329,13 +338,24 @@ class MergeConflictResolver(ConflictResolver):
 
 
 class ListConflictResolver(ConflictResolver):
+    def __init__(self, root=Path('.'), *, list_normal=False, **kwargs):
+        super().__init__(root, **kwargs)
+        self.list_normal = list_normal
+
     def resolve_all(self):
         for f in self.conflict_files():
             print(f)
+            if self.list_normal:
+                print(self.normal_file(f))
+
+
+class ListAllConflictResolver(ListConflictResolver):
+    def __init__(self, root=Path('.'), **kwargs):
+        super().__init__(root, list_normal=True, **kwargs)
 
 
 def to_(s, delimiter='_'):
-    return re.sub('(?!^)([A-Z]+)', delimiter + r'\1', s).lower()
+    return re.sub(r'(?!^)([A-Z]+)', delimiter + r'\1', s).lower()
 
 
 def parse_arguments():
@@ -378,6 +398,9 @@ def parse_arguments():
     class ListConflictResolverAction(ConflictResolverAction):
         pass
 
+    class ListAllConflictResolverAction(ConflictResolverAction):
+        pass
+
     parser.add_argument('dirs', nargs='*', default='.',
                         help="directories to process "
                         "[default: current directory]")
@@ -404,6 +427,11 @@ def parse_arguments():
     conflict_resolver_group.add_argument('-l', '--list',
                                          action=ListConflictResolverAction,
                                          help="list conflict files")
+    conflict_resolver_group.add_argument('-al', '--list-all',
+                                         action=ListAllConflictResolverAction,
+                                         help="list conflict files and "
+                                              "their corresponding normal "
+                                              "files")
     parser.add_argument('-p', '--program', default='',
                         help="program to compare files [default: kdiff3]")
     parser.add_argument('-a', '--arguments', default='',
@@ -446,8 +474,10 @@ def run(args):
         logger.debug("Using {}".format(
             to_(args.conflict_resolver.__name__, delimiter=' ')))
         resolver = args.conflict_resolver(
-            dir_path, args.deleter, args.renamer, program, args.backup)
-        logger.info('Working on directory: "{}"'.format(dir_path))
+            dir_path, deleter=args.deleter, renamer=args.renamer,
+            program=program, backup=args.backup)
+        if len(args.dirs) > 1:
+            logger.info('Working on directory: "{}"'.format(dir_path))
         resolver.resolve_all()
 
 
